==> nextcloud-30.0.15.tar.bz2: nextcloud/apps/encryption/l10n/zh_TW.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "遺失還原金鑰密碼",
    "Please repeat the recovery key password" : "請再次輸入還原金鑰密碼",
    "Repeated recovery key password does not match the provided recovery key password" : "再次輸入的還原金鑰密碼與提供的不相符",
    "Recovery key successfully enabled" : "還原金鑰已成功啟用",
    "Could not enable recovery key. Please check your recovery key password!" : "無法啟用還原金鑰。請檢查您的還原金鑰密碼！",
    "Recovery key successfully disabled" : "還原金鑰已成功停用",
    "Could not disable recovery key. Please check your recovery key password!" : "無法停用還原金鑰。請檢查您的還原金鑰密碼！",
    "Missing parameters" : "遺失參數",
    "Please provide the old recovery password" : "請提供舊的還原密碼",
    "Please provide a new recovery password" : "請提供新的還原密碼",
    "Please repeat the new recovery password" : "請再次輸入新的還原密碼",
    "Password successfully changed." : "成功變更密碼。",
    "Could not change the password. Maybe the old password was not correct." : "無法變更密碼。或許是輸入的舊密碼不正確。",
    "Recovery Key disabled" : "已停用還原金鑰",
    "Recovery Key enabled" : "已啟用還原金鑰",
    "Could not enable the recovery key, please try again or contact your administrator" : "無法啟用還原金鑰，請重試或聯絡系統管理員",
    "Could not update the private key password." : "無法更新私鑰密碼。",
    "The old password was not correct, please try again." : "舊密碼不正確，請再試一次。",
    "The current log-in password was not correct, please try again." : "目前的登入密碼不正確，請再試一次。",
    "Private key password successfully updated." : "私鑰密碼已成功更新。",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "加密應用程式的私鑰無效。請在您的個人設定中更新您的私鑰密碼，以恢復您對加密檔案的存取權。",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "已啟用加密應用程式，但您的金鑰並未初始化。請登出並再次登入。",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "請啟用管理員設定中的伺服器端加密以使用加密模組。",
    "Encryption app is enabled and ready" : "加密應用程式已啟用並準備就緒",
    "Bad Signature" : "不良簽章",
    "Missing Signature" : "遺失簽章",
    "one-time password for server-side-encryption" : "用於伺服器端加密的一次性密碼",
    "Encryption password" : "加密密碼",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "管理員啟用了伺服器端加密。您的檔案已使用密碼 <strong>%s</strong> 加密。",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "管理員啟用了伺服器端加密。您的檔案已使用密碼「%s」加密。",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "請登入網頁介面，請到個人設定中的「安全」區塊，透過輸入此密碼至「舊登入密碼」欄位與您目前的登入密碼，來更新您的加密密碼。",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法解密這個檔案，也許這是分享的檔案。請要求檔案所有人重新分享檔案給您。",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法讀取這個檔案，也許這是分享的檔案。請要求檔案所有人重新分享檔案給您。",
    "Default encryption module" : "預設加密模組",
    "Default encryption module for server-side encryption" : "伺服器端加密的預設加密模組",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "為了使用此加密模組，您必須在管理員設定中啟用伺服器端加密。啟用後，此模組將會加密您之後傳輸的所有檔案。此加密是以 AES 256 金鑰為基礎。\n此模組將不會處理既有的檔案，僅會加密在伺服器端加密啟用後的新檔案。同時也無法停用加密並切換回未加密的系統。\n在您決定啟用伺服器端加密前，請閱讀文件得知其實際作用與影響。",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "已啟用加密應用程式，但您的金鑰並未初始化，請登出並再次登入",
    "Encrypt the home storage" : "加密家目錄儲存空間",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "啟用此功能以加密所有主要儲存空間的檔案，否則僅有外部儲存空間的檔案會被加密",
    "Enable recovery key" : "啟用還原金鑰",
    "Disable recovery key" : "停用還原金鑰",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "還原金鑰是用於加密檔案的額外加密金鑰。其用於忘記密碼時從帳號還原檔案。",
    "Recovery key password" : "還原金鑰密碼",
    "Repeat recovery key password" : "再次輸入還原金鑰密碼",
    "Change recovery key password:" : "變更還原金鑰密碼：",
    "Old recovery key password" : "舊的還原金鑰密碼",
    "New recovery key password" : "新的還原金鑰密碼",
    "Repeat new recovery key password" : "再次輸入新的還原金鑰密碼",
    "Change Password" : "變更密碼",
    "Basic encryption module" : "基本加密模組",
    "Your private key password no longer matches your log-in password." : "您的私鑰密碼與您的登入密碼不相符。",
    "Set your old private key password to your current log-in password:" : "將您的舊私鑰密碼設為您現在的登入密碼：",
    "If you do not remember your old password you can ask your administrator to recover your files." : "如果您忘記舊密碼，可以請求管理員協助取回檔案。",
    "Old log-in password" : "舊登入密碼",
    "Current log-in password" : "目前登入密碼",
    "Update Private Key Password" : "更新私鑰密碼",
    "Enable password recovery:" : "啟用密碼還原：",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "啟用此選項，讓您可以在忘記密碼的情況下，取回對您已加密檔案的存取權",
    "Enabled" : "已啟用",
    "Disabled" : "已停用"
},
"nplurals=1; plural=0;");

==> nextcloud-30.0.17.tar.bz2: nextcloud/apps/encryption/l10n/zh_TW.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "遺失還原金鑰密碼",
    "Please repeat the recovery key password" : "請再次輸入還原金鑰密碼",
    "Repeated recovery key password does not match the provided recovery key password" : "再次輸入的還原金鑰密碼與提供的不相符",
    "Recovery key successfully enabled" : "還原金鑰已成功啟用",
    "Could not enable recovery key. Please check your recovery key password!" : "無法啟用還原金鑰。請檢查您的還原金鑰密碼！",
    "Recovery key successfully disabled" : "還原金鑰已成功停用",
    "Could not disable recovery key. Please check your recovery key password!" : "無法停用還原金鑰。請檢查您的還原金鑰密碼！",
    "Missing parameters" : "遺失參數",
    "Please provide the old recovery password" : "請提供舊的還原密碼",
    "Please provide a new recovery password" : "請提供新的還原密碼",
    "Please repeat the new recovery password" : "請再次輸入新的還原密碼",
    "Password successfully changed." : "成功變更密碼。",
    "Could not change the password. Maybe the old password was not correct." : "無法變更密碼。或許是輸入的舊密碼不正確。",
    "Recovery Key disabled" : "已停用還原金鑰",
    "Recovery Key enabled" : "已啟用還原金鑰",
    "Could not enable the recovery key, please try again or contact your administrator" : "無法啟用還原金鑰，請重試或聯絡系統管理員",
    "Could not update the private key password." : "無法更新私鑰密碼。",
    "The old password was not correct, please try again." : "舊密碼不正確，請再試一次。",
    "The current log-in password was not correct, please try again." : "目前的登入密碼不正確，請再試一次。",
    "Private key password successfully updated." : "私鑰密碼已成功更新。",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "加密應用程式的私鑰無效。請在您的個人設定中更新您的私鑰密碼，以恢復您對加密檔案的存取權。",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "已啟用加密應用程式，但您的金鑰並未初始化。請登出並再次登入。",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "請啟用管理員設定中的伺服器端加密以使用加密模組。",
    "Encryption app is enabled and ready" : "加密應用程式已啟用並準備就緒",
    "Bad Signature" : "不良簽章",
    "Missing Signature" : "遺失簽章",
    "one-time password for server-side-encryption" : "用於伺服器端加密的一次性密碼",
    "Encryption password" : "加密密碼",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "管理員啟用了伺服器端加密。您的檔案已使用密碼 <strong>%s</strong> 加密。",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "管理員啟用了伺服器端加密。您的檔案已使用密碼「%s」加密。",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "請登入網頁介面，請到個人設定中的「安全」區塊，透過輸入此密碼至「舊登入密碼」欄位與您目前的登入密碼，來更新您的加密密碼。",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法解密這個檔案，也許這是分享的檔案。請要求檔案所有人重新分享檔案給您。",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法讀取這個檔案，也許這是分享的檔案。請要求檔案所有人重新分享檔案給您。",
    "Default encryption module" : "預設加密模組",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "已啟用加密應用程式，但您的金鑰並未初始化，請登出並再次登入",
    "Encrypt the home storage" : "加密家目錄儲存空間",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "啟用此功能以加密所有主要儲存空間的檔案，否則僅有外部儲存空間的檔案會被加密",
    "Enable recovery key" : "啟用還原金鑰",
    "Disable recovery key" : "停用還原金鑰",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "還原金鑰是用於加密檔案的額外加密金鑰。其用於忘記密碼時從帳號還原檔案。",
    "Recovery key password" : "還原金鑰密碼",
    "Repeat recovery key password" : "再次輸入還原金鑰密碼",
    "Change recovery key password:" : "變更還原金鑰密碼：",
    "Old recovery key password" : "舊的還原金鑰密碼",
    "New recovery key password" : "新的還原金鑰密碼",
    "Repeat new recovery key password" : "再次輸入新的還原金鑰密碼",
    "Change Password" : "變更密碼",
    "Basic encryption module" : "基本加密模組",
    "Your private key password no longer matches your log-in password." : "您的私鑰密碼與您的登入密碼不相符。",
    "Set your old private key password to your current log-in password:" : "將您的舊私鑰密碼設為您現在的登入密碼：",
    "If you do not remember your old password you can ask your administrator to recover your files." : "如果您忘記舊密碼，可以請求管理員協助取回檔案。",
    "Old log-in password" : "舊登入密碼",
    "Current log-in password" : "目前登入密碼",
    "Update Private Key Password" : "更新私鑰密碼",
    "Enable password recovery:" : "啟用密碼還原：",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "啟用此選項，讓您可以在忘記密碼的情況下，取回對您已加密檔案的存取權",
    "Enabled" : "已啟用",
    "Disabled" : "已停用",
    "Default encryption module for server-side encryption" : "伺服器端加密的預設加密模組",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "為了使用此加密模組，您必須在管理員設定中啟用伺服器端加密。啟用後，此模組將會加密您之後傳輸的所有檔案。此加密是以 AES 256 金鑰為基礎。\n此模組將不會處理既有的檔案，僅會加密在伺服器端加密啟用後的新檔案。同時也無法停用加密並切換回未加密的系統。\n在您決定啟用伺服器端加密前，請閱讀文件得知其實際作用與影響。"
},
"nplurals=1; plural=0;");
